==> plantuml-libs-9.0.0.tgz: package/distribution/aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceService.md <==
# AwsIoTAlexaVoiceService


```text
aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceService
```

```text
include('aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceService')
```



| Illustration | AwsIoTAlexaVoiceService | AwsIoTAlexaVoiceServiceCard | AwsIoTAlexaVoiceServiceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceService.png) | ![illustration for AwsIoTAlexaVoiceService](../../../aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceService.Local.png) | ![illustration for AwsIoTAlexaVoiceServiceCard](../../../aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceServiceCard.Local.png) | ![illustration for AwsIoTAlexaVoiceServiceGroup](../../../aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceServiceGroup.Local.png) |




## AwsIoTAlexaVoiceService

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceService
include('aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceService('AwsIoTAlexaVoiceService', 'Aws Io T Alexa Voice Service', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceService
include('aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceService('AwsIoTAlexaVoiceService', 'Aws Io T Alexa Voice Service', 'an optional tech label')
@enduml
```

## AwsIoTAlexaVoiceServiceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceServiceCard
include('aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceServiceCard('AwsIoTAlexaVoiceServiceCard', 'Aws Io T Alexa Voice Service Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceServiceCard
include('aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceServiceCard('AwsIoTAlexaVoiceServiceCard', 'Aws Io T Alexa Voice Service Card', 'an optional description')
@enduml
```

## AwsIoTAlexaVoiceServiceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceServiceGroup
include('aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceServiceGroup('AwsIoTAlexaVoiceServiceGroup', 'Aws Io T Alexa Voice Service Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceServiceGroup
include('aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceServiceGroup('AwsIoTAlexaVoiceServiceGroup', 'Aws Io T Alexa Voice Service Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceService.md <==
# AwsIoTAlexaVoiceService


```text
aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceService
```

```text
include('aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceService')
```



| Illustration | AwsIoTAlexaVoiceService | AwsIoTAlexaVoiceServiceCard | AwsIoTAlexaVoiceServiceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceService.png) | ![illustration for AwsIoTAlexaVoiceService](../../../aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceService.Local.png) | ![illustration for AwsIoTAlexaVoiceServiceCard](../../../aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceServiceCard.Local.png) | ![illustration for AwsIoTAlexaVoiceServiceGroup](../../../aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceServiceGroup.Local.png) |




## AwsIoTAlexaVoiceService

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceService
include('aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceService('AwsIoTAlexaVoiceService', 'Aws Io T Alexa Voice Service', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceService
include('aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceService('AwsIoTAlexaVoiceService', 'Aws Io T Alexa Voice Service', 'an optional tech label', 'an optional description')
@enduml
```

## AwsIoTAlexaVoiceServiceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceServiceCard
include('aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceServiceCard('AwsIoTAlexaVoiceServiceCard', 'Aws Io T Alexa Voice Service Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceServiceCard
include('aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceServiceCard('AwsIoTAlexaVoiceServiceCard', 'Aws Io T Alexa Voice Service Card', 'an optional description')
@enduml
```

## AwsIoTAlexaVoiceServiceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceServiceGroup
include('aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceServiceGroup('AwsIoTAlexaVoiceServiceGroup', 'Aws Io T Alexa Voice Service Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceServiceGroup
include('aws-q2-2022/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceServiceGroup('AwsIoTAlexaVoiceServiceGroup', 'Aws Io T Alexa Voice Service Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
